# About
**helperpy** is a library that serves a variety of utility functions (in Python)

## Installation
- Make sure you have Python 3.6 or above
- Install via `pip install helperpy` or `pip install helperpy==<version>`

## Documentation
- The documentation for the `helperpy` package can be found at `docs/helperpy/index.html`. You can view this HTML file in your browser after cloning/downloading this repository.
